from pagarme.resources import handler_request
from pagarme.resources.routes import bulk_anticipation_routes


def cancel(recipient_id, bulk_anticipation_id):
    return \
        handler_request.post(bulk_anticipation_routes.CANCEL_ANTICIPATION.format(recipient_id, bulk_anticipation_id))


def confirm(recipient_id, bulk_anticipation_id):
    return \
        handler_request.post(bulk_anticipation_routes.CONFIRM_ANTICIPATION.format(recipient_id, bulk_anticipation_id))


def create(recipient_id, dictionary):
    return handler_request.post(bulk_anticipation_routes.BASE_URL.format(recipient_id), dictionary)


def delete(recipient_id, bulk_anticipation_id):
    return \
        handler_request.delete(bulk_anticipation_routes.DELETE_ANTICIPATION.format(recipient_id, bulk_anticipation_id))


def find_all(recipient_id):
    return handler_request.get(bulk_anticipation_routes.GET_ALL_ANTICIPATIONS.format(recipient_id))


def limits(recipient_id, dictionary):
    return handler_request.get(bulk_anticipation_routes.GET_ANTICIPATION_LIMITS.format(recipient_id), dictionary)



from pagarme.resources.routes.recipient_routes import BASE_URL as BASE_RECIPIENT

BASE_URL = BASE_RECIPIENT + '/{0}/bulk_anticipations'

CANCEL_ANTICIPATION = BASE_URL + '/{1}/cancel'

CONFIRM_ANTICIPATION = BASE_URL + '/{1}/confirm'

DELETE_ANTICIPATION = BASE_URL + '/{1}'

GET_ALL_ANTICIPATIONS = BASE_URL

GET_ANTICIPATION_LIMITS = BASE_URL + '/limits'



from pagarme.resources import handler_request
from pagarme.resources.routes import subscription_routes


def cancel(subscription_id):
    return handler_request.post(subscription_routes.CANCEL_SUBSCRIPTION.format(subscription_id))


def create(dictionary):
    return handler_request.post(subscription_routes.BASE_URL, dictionary)


def find_all():
    return handler_request.get(subscription_routes.GET_ALL_SUBSCRIPTIONS)


def find_by(search_params):
    return handler_request.get(subscription_routes.GET_SUBSCRIPTION_BY, search_params)


def transactions(subscription_id):
    return handler_request.get(subscription_routes.GET_ALL_SUBSCRIPTIONS_TRANSACTIONS.format(subscription_id))


def postbacks(subscription_id):
    return handler_request.get(subscription_routes.GET_ALL_SUBSCRIPTIONS_POSTBACKS.format(subscription_id))


def postback_redeliver(subscription_id, postback_id):
    return \
        handler_request.post(subscription_routes.REDELIVER_SUBSCRIPTION_POSTBACK_BY_ID.format(subscription_id, postback_id))


def settle_charges(subscription_id, dictionary = {}):
    return handler_request.post(subscription_routes.SETTLE_CHARGES_SUBSCRIPTION.format(subscription_id), dictionary)


def update(subscription_id, dictionary):
    return handler_request.put(subscription_routes.UPDATE_SUBSCRIPTION.format(subscription_id), dictionary)



from pagarme.resources.routes import company_routes

BASE_URL = 'https://pagarme.ze.delivery/1/recipients'

GET_ALL_RECIPIENTS = BASE_URL

GET_DEFAULT_RECIPIENT = company_routes.BASE_URL

GET_RECIPIENT_BALANCE = BASE_URL + '/{0}/balance'

GET_RECIPIENT_BALANCE_OPERATIONS = BASE_URL + '/{0}/balance/operations'

GET_RECIPIENT_BALANCE_OPERATION_BY_ID = BASE_URL + '/{0}/balance/operations/{1}'

GET_RECIPIENT_BY = BASE_URL

UPDATE_RECIPIENT = BASE_URL + '/{0}'



from pagarme.resources import handler_request
from pagarme.resources.routes import transaction_routes


def calculate_installments_amount(dictionary):
    return handler_request.get(transaction_routes.CALCULATE_INSTALLMENTS_AMOUNT, dictionary)


def capture(transaction_id, dictionary):
    return handler_request.post(transaction_routes.CAPTURE_TRANSACTION_AFTER.format(transaction_id), dictionary)


def create(dictionary):
    return handler_request.post(transaction_routes.BASE_URL, dictionary)


def events(transaction_id):
    return handler_request.get(transaction_routes.GET_EVENTS_TRANSACTION.format(transaction_id))


def find_all():
    return handler_request.get(transaction_routes.BASE_URL)


def find_by(search_params):
    return handler_request.get(transaction_routes.GET_TRANSACTION_BY, search_params)


def find_by_id(transaction_id):
    return handler_request.get(transaction_routes.GET_SPECIFIC_TRANSACTION_BY_ID.format(transaction_id))


def generate_card_hash_key():
    return handler_request.get(transaction_routes.GENERATE_CARD_HASH_KEY)


def operations(transaction_id):
    return handler_request.get(transaction_routes.GET_TRANSACTION_OPERATION.format(transaction_id))


def pay_boleto(transaction_id, dictionary):
    return handler_request.put(transaction_routes.PAY_BOLETO.format(transaction_id), dictionary)


# def pay_boleto_notify(dictionary):
#    return handler_request.post(transaction_routes.PAY_BOLETO_NOTIFY,dictionary)


def payables(transaction_id):
    return handler_request.get(transaction_routes.GET_ALL_PAYABLES_WITH_TRANSACTION_ID.format(transaction_id))


def postbacks(transaction_id):
    return handler_request.get(transaction_routes.GET_ALL_POSTBACKS.format(transaction_id))


def postback_redeliver(transaction_id, postback_id):
    return handler_request.post(transaction_routes.POSTBACK_REDELIVER.format(transaction_id, postback_id))


def refund(transaction_id, dictionary):
    return handler_request.post(transaction_routes.REFUND_TRANSACTION.format(transaction_id), dictionary)


def specific_payable(transaction_id, payable_id):
    return handler_request.get(transaction_routes.GET_SPECIFIC_PAYABLE.format(transaction_id, payable_id))


def specific_postback(transaction_id, postback_id):
    return handler_request.get(transaction_routes.GET_SPECIFIC_POSTBACK.format(transaction_id, postback_id))

def review(transaction_id,dictionary):
    return handler_request.post(transaction_routes.ANTIFRAUD_ANALYSIS.format(transaction_id),dictionary)


import requests
from pagarme import sdk

TEMPORARY_COMPANY = 'https://pagarme.ze.delivery/1/companies/temporary'

KEYS = {}


def headers():
    _headers = {
        'User-Agent': 'pagarme-python/{}'.format(sdk.VERSION),
        'X-PagarMe-User-Agent': 'pagarme-python/{}'.format(sdk.VERSION)
    }
    return _headers


session = requests.Session()
session.headers.update(headers())


def validate_response(pagarme_response):
    if pagarme_response.ok:
        return pagarme_response.json()
    else:
        return error(pagarme_response.json())


def create_temporary_company():
    company = session.post(TEMPORARY_COMPANY)
    valid_company = validate_response(company)
    return valid_company


def authentication_key(api_key=None, company_temporary=False):
    global KEYS
    if company_temporary is False:
        KEYS['api_key'] = api_key
        return KEYS
    if company_temporary is True:
        company = create_temporary_company()
        api_key = company['api_key']['test']
        KEYS['api_key'] = api_key
        return KEYS


def delete(end_point, data = {}):
    data['api_key'] = KEYS['api_key']
    pagarme_response = session.delete(end_point, json=data)
    return validate_response(pagarme_response)


def get(end_point, data = {}):
    data['api_key'] = KEYS['api_key']
    pagarme_response = session.get(end_point, params=data)
    return validate_response(pagarme_response)


def post(end_point, data={}):
    data['api_key'] = KEYS['api_key']
    pagarme_response = session.post(end_point, json=data)
    return validate_response(pagarme_response)


def put(end_point, data = {}):
    data['api_key'] = KEYS['api_key']
    pagarme_response = session.put(end_point, json=data)
    return validate_response(pagarme_response)


def error(data):
    raise Exception(data['errors'])



from pagarme.resources import handler_request
from pagarme.resources.routes import bank_account_routes


def create(dictionary):
    return handler_request.post(bank_account_routes.BASE_URL, dictionary)


def find_all():
    return handler_request.get(bank_account_routes.BASE_URL)


def find_by(search_params):
    return handler_request.get(bank_account_routes.GET_BANK_ACCOUNTS_BY, search_params)



from pagarme.resources import handler_request
from pagarme.resources.routes import recipient_routes


def create(dictionary):
    return handler_request.post(recipient_routes.BASE_URL, dictionary)


def default_recipient():
    return handler_request.get(recipient_routes.GET_DEFAULT_RECIPIENT)['default_recipient_id']


def find_all():
    return handler_request.get(recipient_routes.GET_ALL_RECIPIENTS)


def find_by(search_params):
    return handler_request.get(recipient_routes.GET_RECIPIENT_BY, search_params)


def recipient_balance(recipient_id):
    return handler_request.get(recipient_routes.GET_RECIPIENT_BALANCE.format(recipient_id))


def recipient_balance_operation(recipient_id):
    return handler_request.get(recipient_routes.GET_RECIPIENT_BALANCE_OPERATIONS.format(recipient_id))


def recipient_balance_operation_id(recipient_id, operation_id):
    return \
        handler_request.get(recipient_routes.GET_RECIPIENT_BALANCE_OPERATION_BY_ID.format(recipient_id, operation_id))


def update_recipient(recipient_id, dictionary):
    return handler_request.put(recipient_routes.UPDATE_RECIPIENT.format(recipient_id), dictionary)



BASE_URL = 'https://pagarme.ze.delivery/1/transactions'

CALCULATE_INSTALLMENTS_AMOUNT = BASE_URL + '/calculate_installments_amount'

CAPTURE_TRANSACTION_AFTER = BASE_URL + '/{0}/capture'

GENERATE_CARD_HASH_KEY = BASE_URL + '/card_hash_key'

GET_ALL_TRANSACTIONS = BASE_URL

GET_SPECIFIC_TRANSACTION_BY_ID = BASE_URL + '/{0}'

GET_ALL_PAYABLES_WITH_TRANSACTION_ID = BASE_URL + '/{0}/payables'

GET_ALL_POSTBACKS = BASE_URL + '/{0}/postbacks'

GET_EVENTS_TRANSACTION = BASE_URL + '/{0}/events'

GET_SPECIFIC_PAYABLE = BASE_URL + '/{0}/payables/{1}'

GET_TRANSACTION_BY = BASE_URL

GET_TRANSACTION_OPERATION = BASE_URL + '/{0}/operations'

GET_SPECIFIC_POSTBACK = BASE_URL + '/{0}/postbacks/{1}'

PAY_BOLETO = BASE_URL + '/{0}'

PAY_BOLETO_NOTIFY = BASE_URL + '/{0}/collect_payment'

POSTBACK_REDELIVER = BASE_URL + '/{0}/postbacks/{1}/redeliver'

REFUND_TRANSACTION = BASE_URL + '/{0}/refund'

ANTIFRAUD_ANALYSIS = BASE_URL + '/{0}/antifraud_analyses'



import binascii
import hmac
import re
from hashlib import sha1
from pagarme.resources.handler_request import KEYS


def validate(signature, payload, api_key=None):
    if api_key is None:
        key = KEYS['api_key'] if 'api_key' in KEYS else None
    else:
        key = api_key

    signature = re.sub('sha1=', '', signature)
    payload = payload.encode('utf-8')

    if key not in(None, ''):
        hashed = hmac.new(key.encode(), payload, sha1)
        hex_signature = binascii.b2a_hex(hashed.digest())
        generated_signature = hex_signature.decode()
    else:
        raise Exception('Missing api_key.')

    return generated_signature == signature



BASE_URL = 'https://pagarme.ze.delivery/1/subscriptions'

CANCEL_SUBSCRIPTION = BASE_URL + '/{0}/cancel'

GET_ALL_SUBSCRIPTIONS = BASE_URL

GET_ALL_SUBSCRIPTIONS_POSTBACKS = BASE_URL + '/{0}/postbacks'

GET_ALL_SUBSCRIPTIONS_TRANSACTIONS = BASE_URL + '/{0}/transactions'

GET_SUBSCRIPTION_BY = BASE_URL

GET_SUBSCRIPTION_POSTBACK_BY_ID = BASE_URL + '/{0}/postbacks/{1}'

REDELIVER_SUBSCRIPTION_POSTBACK_BY_ID = BASE_URL + '/{0}/postbacks/{1}/redeliver'

SETTLE_CHARGES_SUBSCRIPTION = BASE_URL + '/{0}/settle_charge'

UPDATE_SUBSCRIPTION = BASE_URL + '/{0}'



from pagarme.resources import handler_request
from pagarme.resources.routes import plan_routes


def create(params):
    return handler_request.post(plan_routes.BASE_URL, params)


def find_all():
    return handler_request.get(plan_routes.GET_ALL_PLANS)


def find_by(search_params):
    return handler_request.get(plan_routes.GET_PLAN_BY, search_params)


def update(plan_id, dictionary):
    return handler_request.put(plan_routes.UPDATE_PLAN.format(plan_id), dictionary)



from pagarme.resources import handler_request
from pagarme.resources.routes import customer_routes


def create(dictionary):
    return handler_request.post(customer_routes.BASE_URL, dictionary)


def find_all():
    return handler_request.get(customer_routes.GET_ALL_CUSTOMERS)


def find_by(search_params):
    return handler_request.get(customer_routes.GET_CUSTOMER_BY, search_params)


from pagarme.resources import handler_request
from pagarme.resources.routes import card_routes


def create(dictionary):
    return handler_request.post(card_routes.BASE_URL, dictionary)


def find_all():
    return handler_request.get(card_routes.GET_ALL_CARDS)


def find_by(search_params):
    return handler_request.get(card_routes.GET_CARD_BY, search_params)



from pagarme.resources import handler_request
from pagarme.resources.routes import payment_link_routes

def cancel(payment_link_id):
    return handler_request.post(payment_link_routes.CANCEL_PAYMENT_LINK.format(payment_link_id))

def create(dictionary):
    return handler_request.post(payment_link_routes.BASE_URL, dictionary)

def find_all():
    return handler_request.get(payment_link_routes.BASE_URL)

def find_by(search_params):
    return handler_request.get(payment_link_routes.BASE_URL, search_params)

def find_by_id(payment_link_id):
    return handler_request.get(payment_link_routes.PAYMENT_LINK_BY_ID.format(payment_link_id))

def update_by_id(payment_link_id, dictionary):
    return handler_request.put(payment_link_routes.PAYMENT_LINK_BY_ID.format(payment_link_id), dictionary)



from pagarme.resources import handler_request
from pagarme.resources.routes import transfer_routes


def cancel(transfer_id):
    return handler_request.post(transfer_routes.CANCEL_TRANSFER.format(transfer_id))


def create(dictionary):
    return handler_request.post(transfer_routes.BASE_URL, dictionary)


def find_all():
    return handler_request.get(transfer_routes.GET_ALL_TRANSFERS)


def find_by(search_params):
    return handler_request.get(transfer_routes.GET_TRANSFER_BY, search_params)



# -*- coding: utf-8 -*-
import os
import re
from setuptools import setup, find_packages

__description__ = 'Pagar.me Python'
__long_description__ = 'Python library for Pagar.me API'

__author__ = 'Murilo Henrique, Victor Messina'
__author_email__ = 'suporte@pagar.me'
__special_things__ = 'Derek Stavis, Rodrigo Amaral'


testing_extras = [
    'pytest',
    'pytest-cov',
]


install_requires = open('requirements.txt').read().strip().split('\n')


setup(
    name='pagarme-python-custom',
    version='0.0.3',
    author=__author__,
    author_email=__author_email__,
    packages=find_packages(),
    license='MIT',
    description=__description__,
    long_description=__long_description__,
    special_things=__special_things__,
    url='https://github.com/alefhsousa/pagarme-python',
    keywords='Payment, pagarme',
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Topic :: Software Development',
        'Environment :: Web Environment',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'License :: OSI Approved :: MIT License',
    ],
    tests_require=['pytest'],
    extras_require={
        'testing': testing_extras,
    },
)



from pagarme.resources import handler_request
from pagarme.resources.routes import payable_routes


def find_all():
    return handler_request.get(payable_routes.GET_ALL_PAYABLES)


def find_by(search_params):
    return handler_request.get(payable_routes.GET_PAYABLE_BY, search_params)



from pagarme.resources import handler_request
from pagarme.resources.routes import balance_operation_routes


def find_all():
    return handler_request.get(balance_operation_routes.BASE_URL)


def find_by(search_params):
    return handler_request.get(balance_operation_routes.GET_BALANCE_OPERATIONS_BY, search_params)



from pagarme.resources.handler_request import authentication_key
from pagarme import balance
from pagarme import balance_operation
from pagarme import bulk_anticipation
from pagarme import bank_account
from pagarme import card
from pagarme import customer
from pagarme import payable
from pagarme import payment_link
from pagarme import plan
from pagarme import recipient
from pagarme import refund
from pagarme import subscription
from pagarme import transaction
from pagarme import transfer
from pagarme import postback
from pagarme import sdk

